errors

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 9, 2021 License: GPL-3.0 Imports: 3 Imported by: 27

Documentation

Index

Constants

const Version = "1.0.0"

Version is the package version.

Variables

This section is empty.

Functions

func New

func New(str string) error

New will return a new error with a prefixed package name.

func Newf

func Newf(str string, params ...interface{}) error

Newf will return a new error from format string with a prefixed package name.

Types

This section is empty.

Jump to